@@ -291,15 +291,15 @@ print.TrDm <- function(x,...) {
     cat("\t Trackdem color image \n")
     cat(paste("\t Images with size:",d[1],"x",d[2]," pixels.\n"))
     if (length(d) == 4) {
-      cat(paste("\t Total of",d[4],"images, with",d[3],"color layers. \n\n"))
+      cat(paste("\t Total of",d[4],"images. \n\n"))
     } else if (length(d) == 3) {
-      cat(paste("\t Total of 1 image, with",d[3],"color layers. \n\n"))
+      cat(paste("\t Total of 1 image. \n\n"))
     }
   } else if (inherits(x,"sbg")) {
     d <- dim(x)
     cat("\t Trackdem subtracted background image. \n")
     cat(paste("\t Images with size:",d[1],'x',d[2],' pixels. \n'))
-    cat(paste("\t Total of",d[4],"images, with",d[3],"color layers. \n\n"))
+    cat(paste("\t Total of",d[4],"images. \n\n"))
   } else if (inherits(x,"particles")) {
     cat("\t Trackdem list with identified particles (without tracking). \n\n")
   } else if (inherits(x,"tracked")) {
@@ -442,7 +442,7 @@ plot.TrDm <- function(x,frame=1,type=NULL,incThres=NULL,colorimages=NULL,
             tot <- ncol(x)
            for (i in 1:tot) {
               grDevices::png(paste0(path,'/images/images',
-                             formatC(i,width=nchar(tot),flag="0"),'.png'),
+                             formatC(i,width=4,flag="0"),'.png'),
                              width=width,
                              height=height)
               graphics::plot(colorimages,frame=i)
@@ -458,7 +458,7 @@ plot.TrDm <- function(x,frame=1,type=NULL,incThres=NULL,colorimages=NULL,
               grDevices::dev.off()
            }
            system(paste0(libavpath, " -loglevel quiet -r 10 -i ",
-                         path,"/images/images%d.png -b:v 1000k ",
+                         path,"/images/images%04d.png -b:v 1000k ",
                          path,"/",name,".mp4"))
            unlink(paste0(path,"/images"),TRUE)
            cat('\n')
